@@ -25,7 +25,8 @@
 #' @param pr_xi_a Numeric; first shape parameter of beta prior for latent variable xi. default value is 1.
 #' @param pr_xi_b Numeric; second shape parameter of beta prior for latent variable xi. default value is 1.
 #' @param missing.val Numeric; a number to replace missing values. default value is 99.
-#'
+#' @param verbose Logical; If TRUE, MCMC samples are printed for each \code{nprint}. default value is FALSE
+#' 
 #' @return \code{lsirm1pl_mar_ss} returns an object of  list containing the following components:
 #'  \item{data}{data frame or matrix containing the variables in the model.}
 #'  \item{missing.val}{a number to replace missing values.}
@@ -82,19 +83,19 @@ lsirm1pl_mar_ss = function(data, ndim = 2, niter = 15000, nburn = 2500, nthin =
                            jump_beta = 0.4, jump_theta = 1.0, jump_gamma = 1, jump_z = 0.5, jump_w = 0.5,
                            pr_mean_beta = 0, pr_sd_beta = 1.0, pr_mean_theta = 0,
                            pr_spike_mean = -3, pr_spike_sd = 1.0, pr_slab_mean = 0.5, pr_slab_sd = 1.0,
-                           pr_a_theta = 0.001, pr_b_theta = 0.001, pr_xi_a  = 1, pr_xi_b = 1,  missing.val = 99){
+                           pr_a_theta = 0.001, pr_b_theta = 0.001, pr_xi_a  = 1, pr_xi_b = 1,  missing.val = 99, verbose=FALSE){
 
   if(is.data.frame(data)){
     cname = colnames(data)
   }else{
     cname = paste("item", 1:ncol(data), sep=" ")
   }
-
+  cat("\n\nFitting with MCMC algorithm\n")
   output <- lsirm1pl_mar_ss_cpp(as.matrix(data), ndim, niter, nburn, nthin, nprint,
                                 jump_beta, jump_theta, jump_gamma, jump_z, jump_w,
                                 pr_mean_beta, pr_sd_beta, pr_mean_theta,
                                 pr_spike_mean, pr_spike_sd, pr_slab_mean, pr_slab_sd,
-                                pr_a_theta, pr_b_theta, pr_beta_a = pr_xi_a, pr_beta_b = pr_xi_b, missing.val)
+                                pr_a_theta, pr_b_theta, pr_beta_a = pr_xi_a, pr_beta_b = pr_xi_b, missing.val, verbose=verbose)
 
   mcmc.inf = list(nburn=nburn, niter=niter, nthin=nthin)
   nsample <- nrow(data)
@@ -107,7 +108,7 @@ lsirm1pl_mar_ss = function(data, ndim = 2, niter = 15000, nburn = 2500, nthin =
   z.star = output$z[max.address,,]
   w.proc = array(0,dim=c(nmcmc,nitem,ndim))
   z.proc = array(0,dim=c(nmcmc,nsample,ndim))
-
+  cat("\n\nProcrustes Matching Analysis\n")
   for(iter in 1:nmcmc){
     z.iter = output$z[iter,,]
     if(iter != max.address) z.proc[iter,,] = procrustes(z.iter,z.star)$X.new
@@ -134,6 +135,7 @@ lsirm1pl_mar_ss = function(data, ndim = 2, niter = 15000, nburn = 2500, nthin =
   rownames(beta.summary) <- cname
 
   # Calculate BIC
+  cat("\n\nCalculate BIC\n")
   missing_est = ifelse(imp.estimate > 0.5, 1, 0)
   data[data == missing.val] = missing_est
   if(pi.estimate > 0.5){
