@@ -20,7 +20,8 @@
 #' @param pr_b_theta Numeric; scale parameter of inverse gamma prior for variance of theta. default value is 0.001.
 #' @param pr_a_eps Numeric; shape parameter of inverse gamma prior for variance of data likelihood. default value is 0.001.
 #' @param pr_b_eps Numeric; scale parameter of inverse gamma prior for variance of data likelihood default value is 0.001.
-#'
+#' @param verbose Logical; If TRUE, MCMC samples are printed for each \code{nprint}. default value is FALSE
+#' 
 #' @return \code{lsirm1pl_normal_fixed_gamma} returns an object of  list containing the following components:
 #'  \item{data}{data frame or matrix containing the variables in the model.}
 #'  \item{bic}{Numeric value with the corresponding BIC.}
@@ -65,18 +66,18 @@ lsirm1pl_normal_fixed_gamma = function(data, ndim = 2, niter = 15000, nburn = 25
                                        jump_beta = 0.4, jump_theta = 1.0, jump_z = 0.5, jump_w = 0.5,
                                        pr_mean_beta = 0, pr_sd_beta = 1.0, pr_mean_theta = 0,
                                        pr_a_theta = 0.001, pr_b_theta = 0.001,
-                                       pr_a_eps = 0.001, pr_b_eps = 0.001){
+                                       pr_a_eps = 0.001, pr_b_eps = 0.001, verbose=FALSE){
 
   if(is.data.frame(data)){
     cname = colnames(data)
   }else{
     cname = paste("item", 1:ncol(data), sep=" ")
   }
-
+  cat("\n\nFitting with MCMC algorithm\n")
   output <- lsirm1pl_normal_fixed_gamma_cpp(as.matrix(data),  ndim,  niter,  nburn,  nthin,  nprint,
                                             jump_beta, jump_theta, jump_z, jump_w,
                                             pr_mean_beta, pr_sd_beta, pr_mean_theta,
-                                            pr_a_theta, pr_b_theta,  pr_a_eps, pr_b_eps)
+                                            pr_a_theta, pr_b_theta,  pr_a_eps, pr_b_eps, verbose=verbose)
 
   mcmc.inf = list(nburn=nburn, niter=niter, nthin=nthin)
   nsample <- nrow(data)
@@ -89,7 +90,7 @@ lsirm1pl_normal_fixed_gamma = function(data, ndim = 2, niter = 15000, nburn = 25
   z.star = output$z[max.address,,]
   w.proc = array(0,dim=c(nmcmc,nitem,ndim))
   z.proc = array(0,dim=c(nmcmc,nsample,ndim))
-
+  cat("\n\nProcrustes Matching Analysis\n")
   for(iter in 1:nmcmc){
     z.iter = output$z[iter,,]
     if(iter != max.address) z.proc[iter,,] = procrustes(z.iter,z.star)$X.new
@@ -113,6 +114,7 @@ lsirm1pl_normal_fixed_gamma = function(data, ndim = 2, niter = 15000, nburn = 25
   rownames(beta.summary) <- cname
 
   # Calculate BIC
+  cat("\n\nCalculate BIC\n")
   log_like = log_likelihood_normal_cpp(as.matrix(data), ndim, as.matrix(beta.estimate), as.matrix(theta.estimate), 1, z.est, w.est, sigma.estimate, 99)
   p = nitem + nsample + 1 + ndim * nitem + ndim * nsample + 1
   bic = -2 * log_like[[1]] + p * log(nsample * nsample)
