@@ -28,7 +28,8 @@
 #' @param pr_xi_a Numeric; first shape parameter of beta prior for latent variable xi. default value is 1.
 #' @param pr_xi_b Numeric; second shape parameter of beta prior for latent variable xi. default value is 1.
 #' @param missing.val Numeric; a number to replace missing values. default value is 99.
-#'
+#' @param verbose Logical; If TRUE, MCMC samples are printed for each \code{nprint}. default value is FALSE
+#' 
 #' @return \code{lsirm1pl_normal_mcar_ss} returns an object of  list containing the following components:
 #'  \item{data}{data frame or matrix containing the variables in the model.}
 #'  \item{missing.val}{a number to replace missing values.}
@@ -84,7 +85,7 @@ lsirm1pl_normal_mcar_ss = function(data, ndim = 2, niter = 15000, nburn = 2500,
                                    pr_spike_mean = -3, pr_spike_sd = 1.0, pr_slab_mean = 0.5, pr_slab_sd = 1.0,
                                    pr_a_theta = 0.001, pr_b_theta = 0.001,
                                    pr_a_eps = 0.001, pr_b_eps = 0.001,
-                                   pr_xi_a = 0.001, pr_xi_b = 0.001, missing.val = 99){
+                                   pr_xi_a = 0.001, pr_xi_b = 0.001, missing.val = 99, verbose=FALSE){
 
   if(is.data.frame(data)){
     cname = colnames(data)
@@ -92,13 +93,15 @@ lsirm1pl_normal_mcar_ss = function(data, ndim = 2, niter = 15000, nburn = 2500,
     cname = paste("item", 1:ncol(data), sep=" ")
   }
 
+  cat("\n\nFitting with MCMC algorithm\n")
+
   output <- lsirm1pl_normal_mcar_ss_cpp(as.matrix(data), ndim, niter, nburn, nthin, nprint,
                                         jump_beta, jump_theta, jump_gamma, jump_z, jump_w,
                                         pr_mean_beta, pr_sd_beta, pr_mean_theta,
                                         pr_spike_mean, pr_spike_sd, pr_slab_mean, pr_slab_sd,
                                         pr_a_theta, pr_b_theta,
                                         pr_a_eps, pr_b_eps,
-                                        pr_xi_a, pr_xi_b, missing.val)
+                                        pr_xi_a, pr_xi_b, missing.val, verbose=verbose)
 
   mcmc.inf = list(nburn=nburn, niter=niter, nthin=nthin)
   nsample <- nrow(data)
@@ -112,6 +115,8 @@ lsirm1pl_normal_mcar_ss = function(data, ndim = 2, niter = 15000, nburn = 2500,
   w.proc = array(0,dim=c(nmcmc,nitem,ndim))
   z.proc = array(0,dim=c(nmcmc,nsample,ndim))
 
+  cat("\n\nProcrustes Matching Analysis\n")
+
   for(iter in 1:nmcmc){
     z.iter = output$z[iter,,]
     if(iter != max.address) z.proc[iter,,] = procrustes(z.iter,z.star)$X.new
@@ -138,6 +143,7 @@ lsirm1pl_normal_mcar_ss = function(data, ndim = 2, niter = 15000, nburn = 2500,
   rownames(beta.summary) <- cname
 
   # Calculate BIC
+  cat("\n\nCalculate BIC\n")
   if(pi.estimate > 0.5){
     log_like = log_likelihood_normal_cpp(as.matrix(data), ndim, as.matrix(beta.estimate), as.matrix(theta.estimate), gamma.estimate, z.est, w.est, sigma.estimate, missing.val)
   }else{
