@@ -27,7 +27,8 @@
 #' @param pr_a_eps Numeric; shape parameter of inverse gamma prior for variance of data likelihood. default value is 0.001.
 #' @param pr_b_eps Numeric; scale parameter of inverse gamma prior for variance of data likelihood default value is 0.001.
 #' @param missing.val Numeric; a number to replace missing values. default value is 99.
-#'
+#' @param verbose Logical; If TRUE, MCMC samples are printed for each \code{nprint}. default value is FALSE
+#' 
 #' @return \code{lsirm2pl_normal_mcar} returns an object of  list containing the following components:
 #'  \item{data}{data frame or matrix containing the variables in the model.}
 #'  \item{missing.val}{a number to replace missing values.}
@@ -82,7 +83,7 @@ lsirm2pl_normal_mcar = function(data, ndim = 2, niter = 15000, nburn = 2500, nth
                                 pr_mean_gamma = 0.5, pr_sd_gamma =1.0,
                                 pr_mean_alpha = 0.5, pr_sd_alpha = 1,
                                 pr_a_theta = 0.001, pr_b_theta = 0.001,pr_a_eps = 0.001, pr_b_eps = 0.001,
-                                missing.val = 99){
+                                missing.val = 99, verbose=FALSE){
 
   if(is.data.frame(data)){
     cname = colnames(data)
@@ -90,13 +91,15 @@ lsirm2pl_normal_mcar = function(data, ndim = 2, niter = 15000, nburn = 2500, nth
     cname = paste("item", 1:ncol(data), sep=" ")
   }
 
+  cat("\n\nFitting with MCMC algorithm\n")
+
   output <- lsirm2pl_normal_mcar_cpp(as.matrix(data),
                                      ndim, niter, nburn, nthin, nprint,
                                      jump_beta, jump_theta, jump_alpha, jump_gamma, jump_z, jump_w,
                                      pr_mean_beta, pr_sd_beta, pr_a_theta, pr_b_theta, pr_mean_theta,
                                      pr_a_eps, pr_b_eps,
                                      pr_mean_gamma, pr_sd_gamma,
-                                     pr_mean_alpha, pr_sd_alpha, missing.val)
+                                     pr_mean_alpha, pr_sd_alpha, missing.val, verbose=verbose)
 
   mcmc.inf = list(nburn=nburn, niter=niter, nthin=nthin)
   nsample <- nrow(data)
@@ -110,6 +113,8 @@ lsirm2pl_normal_mcar = function(data, ndim = 2, niter = 15000, nburn = 2500, nth
   w.proc = array(0,dim=c(nmcmc,nitem,ndim))
   z.proc = array(0,dim=c(nmcmc,nsample,ndim))
 
+  cat("\n\nProcrustes Matching Analysis\n")
+
   for(iter in 1:nmcmc){
     z.iter = output$z[iter,,]
     if(iter != max.address) z.proc[iter,,] = procrustes(z.iter,z.star)$X.new
@@ -135,6 +140,7 @@ lsirm2pl_normal_mcar = function(data, ndim = 2, niter = 15000, nburn = 2500, nth
   rownames(beta.summary) <- cname
 
   # Calculate BIC
+  cat("\n\nCalculate BIC\n")
   log_like = log_likelihood_normal2pl_cpp(as.matrix(data), ndim, as.matrix(beta.estimate), as.matrix(alpha.estimate), as.matrix(theta.estimate), gamma.estimate, z.est, w.est, sigma.estimate, missing.val)
   p = 2 * nitem + nsample + 1 + 1 + ndim * nitem + ndim * nsample + 1
   bic = -2 * log_like[[1]] + p * log(nsample * nsample)
