@@ -30,7 +30,8 @@
 #' @param pr_b_eps Numeric; scale parameter of inverse gamma prior for variance of data likelihood default value is 0.001.
 #' @param pr_xi_a Numeric; first shape parameter of beta prior for latent variable xi. default value is 1.
 #' @param pr_xi_b Numeric; second shape parameter of beta prior for latent variable xi. default value is 1.
-#'
+#' @param verbose Logical; If TRUE, MCMC samples are printed for each \code{nprint}. default value is FALSE
+#' 
 #' @return \code{lsirm2pl_normal_ss} returns an object of  list containing the following components:
 #'  \item{data}{data frame or matrix containing the variables in the model.}
 #'  \item{bic}{Numeric value with the corresponding BIC.}
@@ -81,7 +82,7 @@ lsirm2pl_normal_ss = function(data, ndim = 2, niter = 15000, nburn = 2500, nthin
                               pr_mean_beta = 0, pr_sd_beta = 1.0, pr_mean_theta = 0,
                               pr_spike_mean = -3, pr_spike_sd = 1.0, pr_slab_mean = 0.5, pr_slab_sd = 1.0,
                               pr_mean_alpha = 0.5, pr_sd_alpha = 1,
-                              pr_a_eps = 0.001, pr_b_eps = 0.001, pr_a_theta = 0.001, pr_b_theta = 0.001, pr_xi_a = 0.001, pr_xi_b = 0.001){
+                              pr_a_eps = 0.001, pr_b_eps = 0.001, pr_a_theta = 0.001, pr_b_theta = 0.001, pr_xi_a = 0.001, pr_xi_b = 0.001, verbose=FALSE){
 
   if(is.data.frame(data)){
     cname = colnames(data)
@@ -89,11 +90,13 @@ lsirm2pl_normal_ss = function(data, ndim = 2, niter = 15000, nburn = 2500, nthin
     cname = paste("item", 1:ncol(data), sep=" ")
   }
 
+  cat("\n\nFitting with MCMC algorithm\n")
+
   output <- lsirm2pl_normal_ss_cpp(as.matrix(data), ndim, niter, nburn, nthin, nprint,
                                    jump_beta, jump_theta, jump_alpha, jump_gamma, jump_z, jump_w,
                                    pr_mean_beta, pr_sd_beta, pr_mean_theta,
                                    pr_spike_mean, pr_spike_sd, pr_slab_mean, pr_slab_sd,  pr_mean_alpha, pr_sd_alpha,
-                                   pr_a_eps,  pr_b_eps, pr_a_theta, pr_b_theta,  pr_xi_a, pr_xi_b)
+                                   pr_a_eps,  pr_b_eps, pr_a_theta, pr_b_theta,  pr_xi_a, pr_xi_b, verbose=verbose)
 
   mcmc.inf = list(nburn=nburn, niter=niter, nthin=nthin)
   nsample <- nrow(data)
@@ -107,6 +110,8 @@ lsirm2pl_normal_ss = function(data, ndim = 2, niter = 15000, nburn = 2500, nthin
   w.proc = array(0,dim=c(nmcmc,nitem,ndim))
   z.proc = array(0,dim=c(nmcmc,nsample,ndim))
 
+  cat("\n\nProcrustes Matching Analysis\n")
+
   for(iter in 1:nmcmc){
     z.iter = output$z[iter,,]
     if(iter != max.address) z.proc[iter,,] = procrustes(z.iter,z.star)$X.new
@@ -134,6 +139,7 @@ lsirm2pl_normal_ss = function(data, ndim = 2, niter = 15000, nburn = 2500, nthin
   rownames(beta.summary) <- cname
 
   # Calculate BIC
+  cat("\n\nCalculate BIC\n")
   if(pi.estimate > 0.5){
     log_like = log_likelihood_normal2pl_cpp(as.matrix(data), ndim, as.matrix(beta.estimate), as.matrix(alpha.estimate), as.matrix(theta.estimate), gamma.estimate, z.est, w.est, sigma.estimate, 99)
   }else{
