@@ -16,9 +16,17 @@ roc_1pl = function(lsirm_result, ...){
   prob = (M1 + M2) - gamma*sqrt(M3 + M4 -2*(z %*% t(w)))
   roc_score = pROC::roc(c(data.matrix(data)),c(prob),
                         levels = c(0,1), direction = "<")
-  # roc_score = pROC::roc(c(data.matrix(data)),c(prob), ...)
-  plot(roc_score, main ="ROC Curve", print.auc = T)
-  return(roc_score$auc)
+
+  auc = round(roc_score$auc,4)
+  legend_text <- paste0("AUC = ", round(auc, 2))
+  rocp = ggroc(roc_score, colour = 'steelblue', size = 2)+
+    theme(axis.text.x = element_text(face="bold",size=15),
+          axis.text.y = element_text( face="bold",size=15),
+          axis.title=element_text(size=15, face='bold'),
+          plot.margin = margin(1,1,1.5,1.2,"cm"))+
+    annotate("text", x = 0.3, y = 0.05, label = legend_text,
+             fontface=2, size=4)
+  return(rocp)
 }
 
 roc_2pl = function(lsirm_result){
@@ -37,11 +45,19 @@ roc_2pl = function(lsirm_result){
   M3 = diag(z %*% t(z)) %*% t(rep(1, p))
   M4 = rep(1, n) %*% t(diag(w %*% t(w)))
   prob = (M1 + M2) - gamma*sqrt(M3 + M4 -2*(z %*% t(w)))
-
   roc_score = pROC::roc(c(data.matrix(data)),c(prob),
                         levels = c(0,1), direction = "<")
-  plot(roc_score, main ="ROC curve", print.auc = T)
-  return(roc_score$auc)
+
+  auc = round(roc_score$auc,4)
+  legend_text <- paste0("AUC = ", round(auc, 2))
+  rocp = ggroc(roc_score, colour = 'steelblue', size = 2)+
+    theme(axis.text.x = element_text(face="bold",size=15),
+          axis.text.y = element_text( face="bold",size=15),
+          axis.title=element_text(size=15, face='bold'),
+          plot.margin = margin(1,1,1.5,1.2,"cm"))+
+    annotate("text", x = 0.3, y = 0.05, label = legend_text,
+             fontface=2, size=4)
+  return(rocp)
 }
 
 
