@@ -1,41 +1,46 @@
 // [[Rcpp::depends(RcppArmadillo)]]
+
 // [[Rcpp::plugins(cpp11)]]
 
+// #include <progress.hpp>
 #include <RcppArmadillo.h>
+#include "progress.h"
 using namespace arma;
 // [[Rcpp::export]]
 Rcpp::List lsirm1pl_cpp(arma::mat data, const int ndim, const int niter, const int nburn, const int nthin, const int nprint,
                  const double jump_beta, const double jump_theta, const double jump_z,const double jump_w,
                  const double pr_mean_beta, const double pr_sd_beta, const double pr_a_theta, const double pr_b_theta, const double pr_mean_theta,
-                 const double pr_mean_gamma, const double pr_sd_gamma, const double jump_gamma){
+                 const double pr_mean_gamma, const double pr_sd_gamma, const double jump_gamma, const bool verbose){
+
+  // Progress p(niter, TRUE);
 
   int i, j, k, count, accept;
   double num, den, old_like_beta, new_like_beta, old_like_theta, new_like_theta, pr_sd_theta = 1.0;
   double old_like_z, new_like_z, old_like_w, new_like_w, old_like_gamma, new_like_gamma ;
   double ratio, un, post_a, post_b, dist_temp, dist_old_temp, dist_new_temp;
   double pr_mean_z = 0.0, pr_sd_z = 1.0, pr_mean_w = 0.0, pr_sd_w = 1.0, mle;
-  
+
   const int nsample = data.n_rows;
   const int nitem = data.n_cols;
-  
+
   arma::dvec oldbeta(nitem, fill::randu);
   oldbeta = oldbeta * 4.0 - 2.0;
   arma::dvec newbeta = oldbeta;
-  
+
   arma::dvec oldtheta(nsample, fill::randu);
   oldtheta = oldtheta * 4.0 - 2.0;
   arma::dvec newtheta = oldtheta;
-  
+
   arma::dmat oldz(nsample,ndim,fill::randu);
   oldz = oldz * 2.0 - 1.0;
   arma::dmat newz = oldz;
-  
+
   arma::dmat oldw(nitem,ndim,fill::randu);
   oldw = oldw * 2.0 - 1.0;
   arma::dmat neww = oldw;
-  
+
   double oldgamma=1, newgamma=1;
-  
+
   arma::dmat samp_beta((niter-nburn)/nthin, nitem, fill::zeros);
   arma::dmat samp_theta((niter-nburn)/nthin, nsample, fill::zeros);
   arma::dcube samp_z(((niter-nburn)/nthin), nsample, ndim, fill::zeros);
@@ -43,13 +48,13 @@ Rcpp::List lsirm1pl_cpp(arma::mat data, const int ndim, const int niter, const i
   arma::dvec samp_sd_theta((niter-nburn)/nthin, fill::zeros);
   arma::dvec sample_mle((niter-nburn)/nthin, fill::zeros);
   arma::dvec samp_gamma(((niter-nburn)/nthin), fill::zeros);
-    
+
   arma::dvec accept_beta(nitem, fill::zeros);
   arma::dvec accept_theta(nsample, fill::zeros);
   arma::dvec accept_z(nsample, fill::zeros);
   arma::dvec accept_w(nitem, fill::zeros);
   double accept_gamma=0;
-  
+
   accept = count = 0;
 
   arma::dmat dist(nsample,nitem,fill::zeros);
@@ -57,8 +62,12 @@ Rcpp::List lsirm1pl_cpp(arma::mat data, const int ndim, const int niter, const i
   arma::dvec new_dist_k(nitem,fill::zeros);
   arma::dvec old_dist_i(nsample,fill::zeros);
   arma::dvec new_dist_i(nsample,fill::zeros);
-  
+
   for(int iter = 0; iter < niter; iter++){
+    // p.increment();
+    if (iter % 10 == 0){
+      Rcpp::checkUserInterrupt();
+    }
 
     //dist(j,i) is distance of z_j and w_i
     dist.fill(0.0);
@@ -128,11 +137,11 @@ Rcpp::List lsirm1pl_cpp(arma::mat data, const int ndim, const int niter, const i
       }
       else newtheta(k) = oldtheta(k);
     }
-    
+
     // gamma update
     newgamma = R::rlnorm(std::log(oldgamma), jump_gamma);
     old_like_gamma = new_like_gamma = 0.0;
-    
+
     for(k = 0; k < nsample; k++){
       for(i = 0; i < nitem; i++){
         if(data(k,i) == 1.0) new_like_gamma += -std::log(1.0 + std::exp(-(oldbeta(i) + oldtheta(k) - newgamma * dist(k,i))));
@@ -141,18 +150,18 @@ Rcpp::List lsirm1pl_cpp(arma::mat data, const int ndim, const int niter, const i
         else old_like_gamma += -std::log(1.0 + std::exp(oldbeta(i) + oldtheta(k) - oldgamma * dist(k,i)));
       }
     }
-    
+
     num = new_like_gamma + R::dlnorm(oldgamma, std::log(newgamma), jump_gamma, 1) + R::dlnorm(newgamma, pr_mean_gamma, pr_sd_gamma, 1);
     den = old_like_gamma + R::dlnorm(newgamma, std::log(oldgamma), jump_gamma, 1) + R::dlnorm(oldgamma, pr_mean_gamma, pr_sd_gamma, 1);
     ratio = num - den;
-    
+
     if(ratio > 0.0) accept = 1;
     else{
       un = R::runif(0,1);
       if(std::log(un) < ratio) accept = 1;
       else accept = 0;
     }
-    
+
     if(accept == 1){
       oldgamma = newgamma;
       accept_gamma += 1.0 / (niter * 1.0);
@@ -163,7 +172,7 @@ Rcpp::List lsirm1pl_cpp(arma::mat data, const int ndim, const int niter, const i
     for(k = 0; k < nsample; k++){
       for(j = 0; j < ndim; j++) newz(k,j) = R::rnorm(oldz(k,j), jump_z);
       old_like_z = new_like_z = 0.0;
-      
+
       //calculate distance of oldw and newz
       for(i = 0; i < nitem; i++){
         dist_old_temp = dist_new_temp = 0.0;
@@ -182,7 +191,7 @@ Rcpp::List lsirm1pl_cpp(arma::mat data, const int ndim, const int niter, const i
         if(data(k,i) == 1.0) old_like_z += -std::log(1.0 + std::exp(-(oldbeta(i) + oldtheta(k) - oldgamma * old_dist_k(i))));
         else old_like_z += -std::log(1.0 + std::exp(oldbeta(i) + oldtheta(k) - oldgamma * old_dist_k(i)));
       }
-      
+
       num = den = 0.0;
       for(j = 0; j < ndim; j++){
         num += R::dnorm4(newz(k,j),pr_mean_z,pr_sd_z,1);
@@ -216,7 +225,7 @@ Rcpp::List lsirm1pl_cpp(arma::mat data, const int ndim, const int niter, const i
     for(i = 0; i < nitem; i++){
       for(j = 0; j < ndim; j++) neww(i,j) = R::rnorm(oldw(i,j), jump_w);
       old_like_w = new_like_w = 0.0;
-      
+
       //calculate distance of neww and oldz
       for(k = 0; k < nsample; k++){
         dist_old_temp = dist_new_temp = 0.0;
@@ -259,16 +268,16 @@ Rcpp::List lsirm1pl_cpp(arma::mat data, const int ndim, const int niter, const i
       }
       else{
         for(j = 0; j < ndim; j++) neww(i,j) = oldw(i,j);
-      } 
+      }
     }
-    
+
     //sigma_theta update with gibbs
     post_a = 2 * pr_a_theta  + nsample;
     post_b = pr_b_theta;
     for(j = 0; j < nsample; j++) post_b += std::pow((oldtheta(j) - pr_mean_theta), 2.0) / 2;
     pr_sd_theta = std::sqrt(2 * post_b *(1.0 /  R::rchisq(post_a)));
-    
-    
+
+
     if(iter >= nburn && iter % nthin == 0){
       for(i = 0; i < nitem; i++) samp_beta(count,i) = oldbeta(i);
       for(k = 0; k < nsample; k++) samp_theta(count,k) = oldtheta(k);
@@ -282,10 +291,10 @@ Rcpp::List lsirm1pl_cpp(arma::mat data, const int ndim, const int niter, const i
           samp_z(count,k,j) = oldz(k,j);
         }
       }
-      
+
       samp_gamma(count) = oldgamma;
       samp_sd_theta(count) = pr_sd_theta;
-      
+
       //dist(j,i) is distance of z_j and w_i
       dist.fill(0.0);
       for(i = 0; i < nitem; i++){
@@ -295,7 +304,7 @@ Rcpp::List lsirm1pl_cpp(arma::mat data, const int ndim, const int niter, const i
           dist(k,i) = std::sqrt(dist_temp);
         }
       }
-      
+
       mle = 0.0;
       for(i = 0; i < nitem; i++) mle += R::dnorm4(oldbeta(i), pr_mean_beta, pr_sd_beta, 1);
       for(k = 0; k < nsample; k++) mle += R::dnorm4(oldtheta(k), pr_mean_theta, pr_sd_theta, 1);
@@ -314,17 +323,24 @@ Rcpp::List lsirm1pl_cpp(arma::mat data, const int ndim, const int niter, const i
       count++;
     } // burn, thin
     
-    if(iter % nprint == 0){
-      Rprintf("Iteration: %.5u ", iter); 
-      for(i = 0 ; i < nitem ; i++ ) {
-        Rprintf("% .3f ", oldbeta(i));
+    if(verbose){
+      int percent = 0;
+      if(iter % nprint == 0){
+        percent = (iter*100)/niter;
+        Rprintf("Iteration: %.5u %3d%% ", iter, percent);
+        for(i = 0 ; i < nitem ; i++ ) {
+          Rprintf("% .3f ", oldbeta(i));
+        }
+        Rprintf(" %.3f ", oldgamma);
+        Rprintf(" %.3f\n", pr_sd_theta);
       }
-      Rprintf(" %.3f ", oldgamma);
-      Rprintf(" %.3f\n", pr_sd_theta);
-      }
-    
+    }else{
+      // progress bar
+      progressbar(iter+1,niter);
+    }
+
     } //for end
-  
+
   Rcpp::List output;
   output["beta"] = samp_beta;
   output["theta"] = samp_theta;
@@ -338,13 +354,13 @@ Rcpp::List lsirm1pl_cpp(arma::mat data, const int ndim, const int niter, const i
   output["accept_z"] = accept_z;
   output["accept_w"] = accept_w;
   output["accept_gamma"] = accept_gamma;
-  
+
   return(output);
-  
+
   } // function end
-  
+
 
 // You can include R code blocks in C++ files processed with sourceCpp
-// (useful for testing and development). The R code will be automatically 
+// (useful for testing and development). The R code will be automatically
 // run after the compilation.
 
